@@ -24,6 +24,7 @@ func (cs *StaticConfigSourcer) readFunc(
 	reqs []*component.ConfigRequest,
 ) ([]*pb.ConfigSource_Value, error) {
 	var results []*pb.ConfigSource_Value
+
 	for _, req := range reqs {
 		if v, ok := req.Config["value"]; ok && v != "" {
 			result := &pb.ConfigSource_Value{Name: req.Name}
@@ -32,6 +33,14 @@ func (cs *StaticConfigSourcer) readFunc(
 			}
 			results = append(results, result)
 		}
+
+		if v, ok := req.Config["json"]; ok && v != "" {
+			result := &pb.ConfigSource_Value{Name: req.Name}
+			result.Result = &pb.ConfigSource_Value_Json{
+				Json: []byte(req.Config["json"]),
+			}
+			results = append(results, result)
+		}
 	}
 
 	return results, nil
