@@ -3,13 +3,13 @@ package cli
 import (
 	"fmt"
 
-	"github.com/golang/protobuf/ptypes/empty"
 	"github.com/posener/complete"
+	empty "google.golang.org/protobuf/types/known/emptypb"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/clierrors"
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 type AuthMethodListCommand struct {
