@@ -4,13 +4,14 @@ import (
 	"fmt"
 
 	"github.com/distribution/distribution/v3/reference"
+
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
-// DefaultODRImage returns the default Waypoint ODR image based on the
+// DeriveDefaultODRImage returns the default Waypoint ODR image based on the
 // supplied server image. We default the ODR image to the name of the server
 // image with the `-odr` suffix attached to it.
-func DefaultODRImage(serverImage string) (string, error) {
+func DeriveDefaultODRImage(serverImage string) (string, error) {
 	image, err := reference.Parse(serverImage)
 	if err != nil {
 		return "", fmt.Errorf("server image name %q is not a valid oci reference: %s", serverImage, err)
@@ -29,11 +30,13 @@ func DefaultODRImage(serverImage string) (string, error) {
 	return fmt.Sprintf("%s-odr:%s", imageName, tag), nil
 }
 
+// NOTE: the server image is also used for static (non-ODR) runners.
+// Static runners cannot use the ODR image.
 const DefaultServerImage = "hashicorp/waypoint:latest"
 
-// When we have a serverImage value to give to DefaultODRImage,
+// When we have a serverImage value to give to DeriveDefaultOdrImage,
 // we should use that. When we don't, we can use this value
-const DefaultRunnerImage = "hashicorp/waypoint-odr:latest"
+const DefaultODRImage = "hashicorp/waypoint-odr:latest"
 
 func DefaultRunnerName(id string) string {
 	return "waypoint-" + id + "-runner"
