@@ -1,6 +1,7 @@
 package boltdbstate
 
 import (
+	"context"
 	"strings"
 	"time"
 
@@ -24,7 +25,7 @@ func init() {
 // ProjectPut creates or updates the given project.
 //
 // Application changes will be ignored, you must use the Application APIs.
-func (s *State) ProjectPut(p *pb.Project) error {
+func (s *State) ProjectPut(ctx context.Context, p *pb.Project) error {
 	memTxn := s.inmem.Txn(true)
 	defer memTxn.Abort()
 
@@ -51,7 +52,7 @@ func (s *State) ProjectPut(p *pb.Project) error {
 }
 
 // ProjectGet gets a project by reference.
-func (s *State) ProjectGet(ref *pb.Ref_Project) (*pb.Project, error) {
+func (s *State) ProjectGet(ctx context.Context, ref *pb.Ref_Project) (*pb.Project, error) {
 	memTxn := s.inmem.Txn(false)
 	defer memTxn.Abort()
 
@@ -68,7 +69,7 @@ func (s *State) ProjectGet(ref *pb.Ref_Project) (*pb.Project, error) {
 // ProjectDelete deletes a project by reference. This is a complete data
 // delete. This will delete all operations associated with this project
 // as well.
-func (s *State) ProjectDelete(ref *pb.Ref_Project) error {
+func (s *State) ProjectDelete(ctx context.Context, ref *pb.Ref_Project) error {
 	memTxn := s.inmem.Txn(true)
 	defer memTxn.Abort()
 	// We perform all of our reads before our write to avoid the deadlocked state
@@ -98,34 +99,34 @@ func (s *State) ProjectDelete(ref *pb.Ref_Project) error {
 				Application: app.Name,
 				Project:     project.Name,
 			}
-			if buildList, err := s.BuildList(appRef); err != nil {
+			if buildList, err := s.BuildList(ctx, appRef); err != nil {
 				return err
 			} else {
 				builds = append(builds, buildList...)
 			}
-			if artifactList, err := s.ArtifactList(appRef); err != nil {
+			if artifactList, err := s.ArtifactList(ctx, appRef); err != nil {
 				return err
 			} else {
 				artifacts = append(artifacts, artifactList...)
 			}
-			if deploymentList, err := s.DeploymentList(appRef); err != nil {
+			if deploymentList, err := s.DeploymentList(ctx, appRef); err != nil {
 				return err
 			} else {
 				deployments = append(deployments, deploymentList...)
 			}
-			if releaseList, err := s.ReleaseList(appRef); err != nil {
+			if releaseList, err := s.ReleaseList(ctx, appRef); err != nil {
 				return err
 			} else {
 				releases = append(releases, releaseList...)
 			}
-			if statusReportList, err := s.StatusReportList(appRef); err != nil {
+			if statusReportList, err := s.StatusReportList(ctx, appRef); err != nil {
 				return err
 			} else {
 				statusReports = append(statusReports, statusReportList...)
 			}
 
 			// Get app-scoped config
-			if appConfigVars, err := s.ConfigGet(&pb.ConfigGetRequest{
+			if appConfigVars, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{Application: &pb.Ref_Application{
 					Project:     project.Name,
 					Application: app.Name,
@@ -137,7 +138,7 @@ func (s *State) ProjectDelete(ref *pb.Ref_Project) error {
 			}
 		}
 		// Get project-scoped config
-		if projectConfigVars, err := s.ConfigGet(&pb.ConfigGetRequest{
+		if projectConfigVars, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 			Scope: &pb.ConfigGetRequest_Project{Project: ref},
 		}); err != nil {
 			return err
@@ -145,17 +146,17 @@ func (s *State) ProjectDelete(ref *pb.Ref_Project) error {
 			configVars = append(configVars, projectConfigVars...)
 		}
 
-		if workspaceList, err := s.ProjectListWorkspaces(ref); err != nil {
+		if workspaceList, err := s.ProjectListWorkspaces(ctx, ref); err != nil {
 			return err
 		} else {
 			for _, workspace := range workspaceList {
 				// Get the triggers for a project in the workspace
-				if triggerList, err := s.TriggerList(workspace.Workspace, &pb.Ref_Project{Project: project.Name}, nil, []string{}); err != nil {
+				if triggerList, err := s.TriggerList(ctx, workspace.Workspace, &pb.Ref_Project{Project: project.Name}, nil, []string{}); err != nil {
 					return err
 				} else {
 					triggers = append(triggers, triggerList...)
 				}
-				if workspaceDetail, err := s.WorkspaceGet(workspace.Workspace.Workspace); err != nil {
+				if workspaceDetail, err := s.WorkspaceGet(ctx, workspace.Workspace.Workspace); err != nil {
 					return err
 				} else {
 					// If the project we're deleting is the only project in the workspace, we delete the workspace
@@ -168,7 +169,7 @@ func (s *State) ProjectDelete(ref *pb.Ref_Project) error {
 			}
 		}
 
-		if pipelines, err = s.PipelineList(ref); err != nil {
+		if pipelines, err = s.PipelineList(ctx, ref); err != nil {
 			return err
 		}
 
@@ -255,16 +256,46 @@ func (s *State) ProjectDelete(ref *pb.Ref_Project) error {
 	return nil
 }
 
-// ProjectList returns the list of projects.
-func (s *State) ProjectList() ([]*pb.Ref_Project, error) {
+func (s *State) ProjectCount(ctx context.Context) (uint64, error) {
 	memTxn := s.inmem.Txn(false)
 	defer memTxn.Abort()
 
-	return s.projectList(memTxn)
+	iter, err := memTxn.Get(projectIndexTableName, projectIndexIdIndexName+"_prefix", "")
+	if err != nil {
+		return 0, err
+	}
+
+	var count uint64
+	for {
+		next := iter.Next()
+		if next == nil {
+			break
+		}
+
+		count++
+	}
+
+	return count, nil
+}
+
+// ProjectList returns the list of projects.
+func (s *State) ProjectList(ctx context.Context, paginationRequest *pb.PaginationRequest) ([]*pb.Ref_Project, *pb.PaginationResponse, error) {
+	memTxn := s.inmem.Txn(false)
+	defer memTxn.Abort()
+
+	return s.projectList(memTxn, paginationRequest)
+}
+
+// ProjectListFull returns the list of full projects (rather than refs).
+func (s *State) ProjectListBundles(ctx context.Context, paginationRequest *pb.PaginationRequest) ([]*pb.UI_ProjectBundle, *pb.PaginationResponse, error) {
+	memTxn := s.inmem.Txn(false)
+	defer memTxn.Abort()
+
+	return s.projectListBundles(memTxn, paginationRequest)
 }
 
 // ProjectListWorkspaces returns the list of workspaces that a project is in.
-func (s *State) ProjectListWorkspaces(ref *pb.Ref_Project) ([]*pb.Workspace_Project, error) {
+func (s *State) ProjectListWorkspaces(ctx context.Context, ref *pb.Ref_Project) ([]*pb.Workspace_Project, error) {
 	memTxn := s.inmem.Txn(false)
 	defer memTxn.Abort()
 
@@ -290,7 +321,7 @@ func (s *State) ProjectListWorkspaces(ref *pb.Ref_Project) ([]*pb.Workspace_Proj
 // projects to poll are added. This is important functionality since callers
 // may be sleeping on a deadline for awhile when a new project is inserted
 // to poll immediately.
-func (s *State) ProjectPollPeek(ws memdb.WatchSet) (*pb.Project, time.Time, error) {
+func (s *State) ProjectPollPeek(ctx context.Context, ws memdb.WatchSet) (*pb.Project, time.Time, error) {
 	memTxn := s.inmem.Txn(false)
 	defer memTxn.Abort()
 
@@ -345,7 +376,7 @@ func (s *State) ProjectPollPeek(ws memdb.WatchSet) (*pb.Project, time.Time, erro
 
 // ProjectPollComplete sets the next poll time for the given project to the
 // time "t" plus the interval time for the project.
-func (s *State) ProjectPollComplete(p *pb.Project, t time.Time) error {
+func (s *State) ProjectPollComplete(ctx context.Context, p *pb.Project, t time.Time) error {
 	memTxn := s.inmem.Txn(true)
 	defer memTxn.Abort()
 
@@ -384,6 +415,7 @@ func (s *State) ProjectPollComplete(p *pb.Project, t time.Time) error {
 // ProjectUpdateDataRef updates the latest data ref used for a project.
 // This data is available via the APIs for querying workspaces.
 func (s *State) ProjectUpdateDataRef(
+	ctx context.Context,
 	ref *pb.Ref_Project,
 	ws *pb.Ref_Workspace,
 	dataRef *pb.Job_DataSource_Ref,
@@ -460,10 +492,11 @@ func (s *State) projectGet(
 
 func (s *State) projectList(
 	memTxn *memdb.Txn,
-) ([]*pb.Ref_Project, error) {
+	paginationRequest *pb.PaginationRequest,
+) ([]*pb.Ref_Project, *pb.PaginationResponse, error) {
 	iter, err := memTxn.Get(projectIndexTableName, projectIndexIdIndexName+"_prefix", "")
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
 	var result []*pb.Ref_Project
@@ -479,7 +512,48 @@ func (s *State) projectList(
 		})
 	}
 
-	return result, nil
+	return result, &pb.PaginationResponse{}, nil // TODO (andrew): fill in for boltdb
+}
+
+// projectListBundles returns a list of project bundles — that is, projects with
+// additional preloaded data. There is no additional data at present, but we expect
+// to add `latest_init_job` and `latest_destroy_job` in the near future.
+func (s *State) projectListBundles(
+	memTxn *memdb.Txn,
+	paginationRequest *pb.PaginationRequest,
+) ([]*pb.UI_ProjectBundle, *pb.PaginationResponse, error) {
+	// Get the index
+	iter, err := memTxn.Get(projectIndexTableName, projectIndexIdIndexName+"_prefix", "")
+	if err != nil {
+		return nil, nil, err
+	}
+
+	// Populate the result slice
+	var result []*pb.UI_ProjectBundle
+	err = s.db.View(func(dbTxn *bolt.Tx) error {
+		for {
+			next := iter.Next()
+			if next == nil {
+				break
+			}
+			idx := next.(*projectIndexRecord)
+			ref := &pb.Ref_Project{
+				Project: idx.Id,
+			}
+
+			project, err := s.projectGet(dbTxn, memTxn, ref)
+			if err != nil {
+				return err
+			}
+			result = append(result, &pb.UI_ProjectBundle{Project: project})
+		}
+		return nil
+	})
+	if err != nil {
+		return nil, nil, err
+	}
+
+	return result, &pb.PaginationResponse{}, nil // TODO(jgwhite): pagination for ProjectListFull
 }
 
 func (s *State) projectDelete(
