@@ -1,12 +1,14 @@
 package boltdbstate
 
 import (
+	"context"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 	"github.com/stretchr/testify/require"
 	"testing"
 )
 
 func TestProject(t *testing.T) {
+	ctx := context.Background()
 	t.Run("create and get and delete", func(t *testing.T) {
 		require := require.New(t)
 
@@ -16,7 +18,7 @@ func TestProject(t *testing.T) {
 		const projectName = "testproject"
 		const appName = "testapp"
 		// Create a project with one app
-		require.NoError(s.ProjectPut(&pb.Project{
+		require.NoError(s.ProjectPut(ctx, &pb.Project{
 			Name: projectName,
 			Applications: []*pb.Application{
 				{
@@ -27,13 +29,13 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Read it back
-		projectBeforeDelete, err := s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		projectBeforeDelete, err := s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.NoError(err)
 		require.NotNil(projectBeforeDelete)
 
 		// Create a build, artifact, deployment, release, trigger, workspace, and pipeline
 		// Set a config at the project and app scope
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -42,7 +44,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -51,7 +53,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -60,7 +62,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -69,7 +71,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.StatusReportPut(false, &pb.StatusReport{
+		require.NoError(s.StatusReportPut(ctx, false, &pb.StatusReport{
 			Id: "testStatusReport",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -78,7 +80,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Project{Project: &pb.Ref_Project{Project: projectName}},
 			},
@@ -88,7 +90,7 @@ func TestProject(t *testing.T) {
 			NameIsPath: false,
 		}))
 
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{Application: &pb.Ref_Application{
 					Project:     projectName,
@@ -101,7 +103,7 @@ func TestProject(t *testing.T) {
 			NameIsPath: false,
 		}))
 
-		require.NoError(s.WorkspacePut(&pb.Workspace{
+		require.NoError(s.WorkspacePut(ctx, &pb.Workspace{
 			Name: "testWorkspace",
 			Projects: []*pb.Workspace_Project{
 				{
@@ -110,7 +112,7 @@ func TestProject(t *testing.T) {
 			},
 		}))
 
-		require.NoError(s.PipelinePut(&pb.Pipeline{
+		require.NoError(s.PipelinePut(ctx, &pb.Pipeline{
 			Id:   "testPipeline",
 			Name: "testPipeline",
 			Owner: &pb.Pipeline_Project{
@@ -128,7 +130,7 @@ func TestProject(t *testing.T) {
 			},
 		}))
 
-		require.NoError(s.TriggerPut(&pb.Trigger{
+		require.NoError(s.TriggerPut(ctx, &pb.Trigger{
 			Id:        "testTrigger",
 			Name:      "testTrigger",
 			Project:   &pb.Ref_Project{Project: projectName},
@@ -136,40 +138,40 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Delete the project (this should also delete the build)
-		require.NoError(s.ProjectDelete(&pb.Ref_Project{Project: projectName}))
+		require.NoError(s.ProjectDelete(ctx, &pb.Ref_Project{Project: projectName}))
 
 		// Attempt to get the project again (expected error)
-		_, err = s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		_, err = s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.Error(err)
 
 		// Verify that all builds, artifacts, deployments, releases, status reports,
 		// triggers, pipelines and workspaces were deleted, and that configs were unset
-		_, err = s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild"}})
+		_, err = s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild"}})
 		require.Error(err)
 
-		_, err = s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact"}})
+		_, err = s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact"}})
 		require.Error(err)
 
-		_, err = s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment"}})
+		_, err = s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment"}})
 		require.Error(err)
 
-		_, err = s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease"}})
+		_, err = s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease"}})
 		require.Error(err)
 
-		_, err = s.StatusReportGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport"}})
+		_, err = s.StatusReportGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport"}})
 		require.Error(err)
 
-		configVars, err := s.ConfigGet(&pb.ConfigGetRequest{})
+		configVars, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{})
 		require.NoError(err)
 		require.Equal(0, len(configVars))
 
-		_, err = s.WorkspaceGet("testWorkspace")
+		_, err = s.WorkspaceGet(ctx, "testWorkspace")
 		require.Error(err)
 
-		_, err = s.TriggerGet(&pb.Ref_Trigger{Id: "testTrigger"})
+		_, err = s.TriggerGet(ctx, &pb.Ref_Trigger{Id: "testTrigger"})
 		require.Error(err)
 
-		_, err = s.PipelineGet(&pb.Ref_Pipeline{Ref: &pb.Ref_Pipeline_Owner{Owner: &pb.Ref_PipelineOwner{
+		_, err = s.PipelineGet(ctx, &pb.Ref_Pipeline{Ref: &pb.Ref_Pipeline_Owner{Owner: &pb.Ref_PipelineOwner{
 			Project:      &pb.Ref_Project{Project: projectName},
 			PipelineName: "testPipeline",
 		}}})
@@ -186,7 +188,7 @@ func TestProject(t *testing.T) {
 		const appName1 = "testapp1"
 		const projectName2 = "testproject2"
 		const appName2 = "testapp2"
-		require.NoError(s.ProjectPut(&pb.Project{
+		require.NoError(s.ProjectPut(ctx, &pb.Project{
 			Name: projectName1,
 			Applications: []*pb.Application{
 				{
@@ -196,7 +198,7 @@ func TestProject(t *testing.T) {
 			},
 		}))
 
-		require.NoError(s.ProjectPut(&pb.Project{
+		require.NoError(s.ProjectPut(ctx, &pb.Project{
 			Name: projectName2,
 			Applications: []*pb.Application{
 				{
@@ -206,7 +208,7 @@ func TestProject(t *testing.T) {
 			},
 		}))
 
-		require.NoError(s.WorkspacePut(&pb.Workspace{
+		require.NoError(s.WorkspacePut(ctx, &pb.Workspace{
 			Name: "one-project-workspace",
 			Projects: []*pb.Workspace_Project{
 				{
@@ -216,7 +218,7 @@ func TestProject(t *testing.T) {
 			ActiveTime: nil,
 		}))
 
-		require.NoError(s.WorkspacePut(&pb.Workspace{
+		require.NoError(s.WorkspacePut(ctx, &pb.Workspace{
 			Name: "two-project-workspace",
 			Projects: []*pb.Workspace_Project{
 				{
@@ -229,9 +231,9 @@ func TestProject(t *testing.T) {
 			ActiveTime: nil,
 		}))
 
-		require.NoError(s.ProjectDelete(&pb.Ref_Project{Project: projectName1}))
+		require.NoError(s.ProjectDelete(ctx, &pb.Ref_Project{Project: projectName1}))
 
-		workspaces, err := s.WorkspaceList()
+		workspaces, err := s.WorkspaceList(ctx)
 		require.NoError(err)
 
 		// After the project is deleted, only the 2nd workspace should exist
@@ -250,7 +252,7 @@ func TestProject(t *testing.T) {
 			appName2    = "testapp2"
 		)
 		// Create a project with one app
-		require.NoError(s.ProjectPut(&pb.Project{
+		require.NoError(s.ProjectPut(ctx, &pb.Project{
 			Name: projectName,
 			Applications: []*pb.Application{
 				{
@@ -265,12 +267,12 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Read it back
-		projectBeforeDelete, err := s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		projectBeforeDelete, err := s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.NoError(err)
 		require.NotNil(projectBeforeDelete)
 
 		// Create multiple builds for each app
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id:       "testBuild1App1",
 			Sequence: 1,
 			Application: &pb.Ref_Application{
@@ -280,7 +282,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id:       "testBuild2App1",
 			Sequence: 2,
 			Application: &pb.Ref_Application{
@@ -290,7 +292,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild1App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -299,7 +301,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild2App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -309,7 +311,7 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Create multiple artifacts for each app
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -318,7 +320,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact2",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -327,7 +329,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact1",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -336,7 +338,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -346,7 +348,7 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Create multiple deployments for each app
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment1App1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -355,7 +357,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment2App1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -364,7 +366,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment1App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -373,7 +375,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment2App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -383,7 +385,7 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Create multiple releases for each app
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease1App1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -392,7 +394,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease2App1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -401,7 +403,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease1App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -410,7 +412,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease2App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -420,7 +422,7 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Create multiple status reports for each app
-		require.NoError(s.StatusReportPut(false, &pb.StatusReport{
+		require.NoError(s.StatusReportPut(ctx, false, &pb.StatusReport{
 			Id: "testStatusReport1App1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -429,7 +431,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.StatusReportPut(false, &pb.StatusReport{
+		require.NoError(s.StatusReportPut(ctx, false, &pb.StatusReport{
 			Id: "testStatusReport2App1",
 			Application: &pb.Ref_Application{
 				Application: appName1,
@@ -438,7 +440,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.StatusReportPut(false, &pb.StatusReport{
+		require.NoError(s.StatusReportPut(ctx, false, &pb.StatusReport{
 			Id: "testStatusReport1App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -447,7 +449,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.StatusReportPut(false, &pb.StatusReport{
+		require.NoError(s.StatusReportPut(ctx, false, &pb.StatusReport{
 			Id: "testStatusReport2App2",
 			Application: &pb.Ref_Application{
 				Application: appName2,
@@ -457,71 +459,71 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Delete the project (this should also delete the other records)
-		require.NoError(s.ProjectDelete(&pb.Ref_Project{Project: projectName}))
+		require.NoError(s.ProjectDelete(ctx, &pb.Ref_Project{Project: projectName}))
 
 		// Attempt to get the project again (expected error)
-		_, err = s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		_, err = s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.Error(err)
 
 		// Verify that all builds, artifacts, deployments, releases, and status reports were deleted with the project
-		_, err = s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild1App1"}})
+		_, err = s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild1App1"}})
 		require.Error(err)
 
-		_, err = s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild2App1"}})
+		_, err = s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild2App1"}})
 		require.Error(err)
 
-		_, err = s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild1App2"}})
+		_, err = s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild1App2"}})
 		require.Error(err)
 
-		_, err = s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild2App2"}})
+		_, err = s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild2App2"}})
 		require.Error(err)
 
-		_, err = s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact1App1"}})
+		_, err = s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact1App1"}})
 		require.Error(err)
 
-		_, err = s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact2App1"}})
+		_, err = s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact2App1"}})
 		require.Error(err)
 
-		_, err = s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact1App2"}})
+		_, err = s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact1App2"}})
 		require.Error(err)
 
-		_, err = s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact2App2"}})
+		_, err = s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact2App2"}})
 		require.Error(err)
 
-		_, err = s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment1App1"}})
+		_, err = s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment1App1"}})
 		require.Error(err)
 
-		_, err = s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment2App1"}})
+		_, err = s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment2App1"}})
 		require.Error(err)
 
-		_, err = s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment1App2"}})
+		_, err = s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment1App2"}})
 		require.Error(err)
 
-		_, err = s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment2App2"}})
+		_, err = s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment2App2"}})
 		require.Error(err)
 
-		_, err = s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease1App1"}})
+		_, err = s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease1App1"}})
 		require.Error(err)
 
-		_, err = s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease2App1"}})
+		_, err = s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease2App1"}})
 		require.Error(err)
 
-		_, err = s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease1App2"}})
+		_, err = s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease1App2"}})
 		require.Error(err)
 
-		_, err = s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease2App2"}})
+		_, err = s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease2App2"}})
 		require.Error(err)
 
-		_, err = s.StatusReportGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport1App1"}})
+		_, err = s.StatusReportGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport1App1"}})
 		require.Error(err)
 
-		_, err = s.StatusReportGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport2App1"}})
+		_, err = s.StatusReportGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport2App1"}})
 		require.Error(err)
 
-		_, err = s.StatusReportGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport1App2"}})
+		_, err = s.StatusReportGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport1App2"}})
 		require.Error(err)
 
-		_, err = s.StatusReportGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport2App2"}})
+		_, err = s.StatusReportGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testStatusReport2App2"}})
 		require.Error(err)
 	})
 
@@ -534,7 +536,7 @@ func TestProject(t *testing.T) {
 		const projectName = "projecttestsequence"
 		const appName = "apptestsequence"
 		// Create a project with one app
-		require.NoError(s.ProjectPut(&pb.Project{
+		require.NoError(s.ProjectPut(ctx, &pb.Project{
 			Name: projectName,
 			Applications: []*pb.Application{
 				{
@@ -545,13 +547,13 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Read it back
-		projectBeforeDelete, err := s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		projectBeforeDelete, err := s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.NoError(err)
 		require.NotNil(projectBeforeDelete)
 
 		// Create a build, artifact, deployment, release, trigger, workspace, and pipeline
 		// Set a config at the project and app scope
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -560,7 +562,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -570,14 +572,14 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Delete the project (this should also delete the build)
-		require.NoError(s.ProjectDelete(&pb.Ref_Project{Project: projectName}))
+		require.NoError(s.ProjectDelete(ctx, &pb.Ref_Project{Project: projectName}))
 
 		// Attempt to get the project again (expected error)
-		_, err = s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		_, err = s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.Error(err)
 
 		// Re-create the project
-		require.NoError(s.ProjectPut(&pb.Project{
+		require.NoError(s.ProjectPut(ctx, &pb.Project{
 			Name: projectName,
 			Applications: []*pb.Application{
 				{
@@ -588,12 +590,12 @@ func TestProject(t *testing.T) {
 		}))
 
 		// Read it back
-		projectAfterReInit, err := s.ProjectGet(&pb.Ref_Project{Project: projectName})
+		projectAfterReInit, err := s.ProjectGet(ctx, &pb.Ref_Project{Project: projectName})
 		require.NoError(err)
 		require.NotNil(projectAfterReInit)
 
 		// Create new build after the project is re-initialized
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild1",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -602,7 +604,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild2",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -611,7 +613,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.BuildPut(false, &pb.Build{
+		require.NoError(s.BuildPut(ctx, false, &pb.Build{
 			Id: "testBuild3",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -620,7 +622,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact1",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -629,7 +631,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact2",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -638,7 +640,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ArtifactPut(false, &pb.PushedArtifact{
+		require.NoError(s.ArtifactPut(ctx, false, &pb.PushedArtifact{
 			Id: "testArtifact3",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -647,7 +649,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment1",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -656,7 +658,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment2",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -665,7 +667,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.DeploymentPut(false, &pb.Deployment{
+		require.NoError(s.DeploymentPut(ctx, false, &pb.Deployment{
 			Id: "testDeployment3",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -674,7 +676,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease1",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -683,7 +685,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease2",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -692,7 +694,7 @@ func TestProject(t *testing.T) {
 			Workspace: &pb.Ref_Workspace{Workspace: "default"},
 		}))
 
-		require.NoError(s.ReleasePut(false, &pb.Release{
+		require.NoError(s.ReleasePut(ctx, false, &pb.Release{
 			Id: "testRelease3",
 			Application: &pb.Ref_Application{
 				Application: appName,
@@ -703,49 +705,49 @@ func TestProject(t *testing.T) {
 
 		// Verify that the app operation sequence is 1, since it is the 1st operation for the new (albeit
 		// re-initialized it was deleted) project
-		build1, err := s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild1"}})
+		build1, err := s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild1"}})
 		require.NoError(err)
 		require.Equal(1, int(build1.Sequence))
-		build2, err := s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild2"}})
+		build2, err := s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild2"}})
 		require.NoError(err)
 		require.Equal(2, int(build2.Sequence))
-		build3, err := s.BuildGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild3"}})
+		build3, err := s.BuildGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testBuild3"}})
 		require.NoError(err)
 		require.Equal(3, int(build3.Sequence))
 
-		artifact1, err := s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact1"}})
+		artifact1, err := s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact1"}})
 		require.NoError(err)
 		require.Equal(1, int(artifact1.Sequence))
 
-		artifact2, err := s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact2"}})
+		artifact2, err := s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact2"}})
 		require.NoError(err)
 		require.Equal(2, int(artifact2.Sequence))
 
-		artifact3, err := s.ArtifactGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact3"}})
+		artifact3, err := s.ArtifactGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testArtifact3"}})
 		require.NoError(err)
 		require.Equal(3, int(artifact3.Sequence))
 
-		deployment1, err := s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment1"}})
+		deployment1, err := s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment1"}})
 		require.NoError(err)
 		require.Equal(1, int(deployment1.Sequence))
 
-		deployment2, err := s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment2"}})
+		deployment2, err := s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment2"}})
 		require.NoError(err)
 		require.Equal(2, int(deployment2.Sequence))
 
-		deployment3, err := s.DeploymentGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment3"}})
+		deployment3, err := s.DeploymentGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testDeployment3"}})
 		require.NoError(err)
 		require.Equal(3, int(deployment3.Sequence))
 
-		release1, err := s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease1"}})
+		release1, err := s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease1"}})
 		require.NoError(err)
 		require.Equal(1, int(release1.Sequence))
 
-		release2, err := s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease2"}})
+		release2, err := s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease2"}})
 		require.NoError(err)
 		require.Equal(2, int(release2.Sequence))
 
-		release3, err := s.ReleaseGet(&pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease3"}})
+		release3, err := s.ReleaseGet(ctx, &pb.Ref_Operation{Target: &pb.Ref_Operation_Id{Id: "testRelease3"}})
 		require.NoError(err)
 		require.Equal(3, int(release3.Sequence))
 	})
