@@ -33,7 +33,7 @@ func TestApplication(t testing.T, src *pb.Application) *pb.Application {
 func ValidateUpsertApplicationRequest(v *pb.UpsertApplicationRequest) error {
 	return validationext.Error(validation.ValidateStruct(v,
 		validation.Field(&v.Project, validation.Required),
-		validation.Field(&v.Name, validation.Required),
+		validation.Field(&v.Name, validation.Required, validation.By(validatePathToken)),
 	))
 }
 
