@@ -76,7 +76,7 @@ func UserWithContext(ctx context.Context, u *pb.User) context.Context {
 // UserFromContext returns the authenticated user in the request context.
 // This will return nil if the user is not authenticated. Note that a user
 // may not be authenticated but the request can still be authenticated
-// using a non-user token type. The safeste way to check is decodedTokenFromContext.
+// using a non-user token type. The safest way to check is decodedTokenFromContext.
 func (s *Service) UserFromContext(ctx context.Context) *pb.User {
 	value, ok := ctx.Value(userKey{}).(*pb.User)
 	if !ok && s.superuser {
@@ -449,6 +449,10 @@ func (s *Service) GenerateLoginToken(
 
 	// Get our user, that's what we log in as
 	currentUser := s.UserFromContext(ctx)
+	if currentUser == nil {
+		return nil,
+			status.Error(codes.Unauthenticated, "no user found from current context")
+	}
 
 	// If we have a duration set, set the expiry
 	var dur time.Duration
