@@ -5,7 +5,9 @@ import (
 
 	empty "google.golang.org/protobuf/types/known/emptypb"
 
+	"github.com/hashicorp/go-hclog"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	"github.com/hashicorp/waypoint/pkg/server/ptypes"
 )
 
@@ -13,8 +15,8 @@ func (s *Service) SetConfig(
 	ctx context.Context,
 	req *pb.ConfigSetRequest,
 ) (*pb.ConfigSetResponse, error) {
-	if err := s.state(ctx).ConfigSet(req.Variables...); err != nil {
-		return nil, err
+	if err := s.state(ctx).ConfigSet(ctx, req.Variables...); err != nil {
+		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to set config")
 	}
 
 	return &pb.ConfigSetResponse{}, nil
@@ -28,9 +30,9 @@ func (s *Service) GetConfig(
 		return nil, err
 	}
 
-	vars, err := s.state(ctx).ConfigGet(req)
+	vars, err := s.state(ctx).ConfigGet(ctx, req)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to get config")
 	}
 
 	return &pb.ConfigGetResponse{Variables: vars}, nil
@@ -44,8 +46,12 @@ func (s *Service) SetConfigSource(
 		return nil, err
 	}
 
-	if err := s.state(ctx).ConfigSourceSet(req.ConfigSource); err != nil {
-		return nil, err
+	if err := s.state(ctx).ConfigSourceSet(ctx, req.ConfigSource); err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to set config source",
+		)
 	}
 
 	return &empty.Empty{}, nil
@@ -59,9 +65,13 @@ func (s *Service) GetConfigSource(
 		return nil, err
 	}
 
-	vars, err := s.state(ctx).ConfigSourceGet(req)
+	vars, err := s.state(ctx).ConfigSourceGet(ctx, req)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get config source",
+		)
 	}
 
 	return &pb.GetConfigSourceResponse{ConfigSources: vars}, nil
