@@ -2,6 +2,7 @@ package singleprocess
 
 import (
 	"context"
+	"fmt"
 	"sync"
 
 	"github.com/hashicorp/go-hclog"
@@ -13,6 +14,7 @@ import (
 	"github.com/hashicorp/waypoint/pkg/server"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 	"github.com/hashicorp/waypoint/pkg/server/grpcmetadata"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	"github.com/hashicorp/waypoint/pkg/server/logbuffer"
 	"github.com/hashicorp/waypoint/pkg/serverstate"
 )
@@ -52,7 +54,7 @@ func (s *Service) spawnLogPlugin(
 	var lo boltdbstate.InstanceLogs
 	lo.LogBuffer = logbuffer.New()
 
-	err = inmemstate.InstanceLogsCreate(instId, &lo)
+	err = inmemstate.InstanceLogsCreate(ctx, instId, &lo)
 	if err != nil {
 		return nil, "", err
 	}
@@ -172,13 +174,19 @@ func (s *Service) GetLogStream(
 
 	switch scope := req.Scope.(type) {
 	case *pb.GetLogStreamRequest_DeploymentId:
-		deployment, err := s.state(ctx).DeploymentGet(&pb.Ref_Operation{
+		deployment, err := s.state(ctx).DeploymentGet(ctx, &pb.Ref_Operation{
 			Target: &pb.Ref_Operation_Id{
 				Id: scope.DeploymentId,
 			},
 		})
 		if err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"failed to get deployment in get log stream",
+				"deployment_id",
+				scope.DeploymentId,
+			)
 		}
 
 		log = log.With("deployment_id", scope.DeploymentId)
@@ -189,16 +197,19 @@ func (s *Service) GetLogStream(
 			log.Debug("deployment supports log plugin. spawning log plugin")
 			inst, jobId, err := s.spawnLogPlugin(srv.Context(), log, deployment)
 			if err != nil {
-				log.Warn("error spawning log plugin", "err", err)
-				return err
+				return hcerr.Externalize(
+					log,
+					fmt.Errorf("error spawning log plugin: %w", err),
+					"error spawning log plugin",
+				)
 			}
 
 			// Be sure to cleanup when we, the job creator, are finished.
-			defer s.state(ctx).JobCancel(jobId, false)
+			defer s.state(ctx).JobCancel(ctx, jobId, false)
 
 			// Because we spawned the writer, we can safely delete the whole thing
 			// when the reader is done.
-			defer inmemstate.InstanceLogsDelete(inst.Id)
+			defer inmemstate.InstanceLogsDelete(ctx, inst.Id)
 
 			log.Debug("log plugin spawned", "job_id", jobId)
 			instanceFunc = func(ws memdb.WatchSet) ([]*streamRec, error) {
@@ -212,9 +223,15 @@ func (s *Service) GetLogStream(
 			log.Debug("deployment log will watch connected instances")
 			instanceLog := log.Named("instancefunc")
 			instanceFunc = func(ws memdb.WatchSet) ([]*streamRec, error) {
-				instances, err := s.state(ctx).InstancesByDeployment(scope.DeploymentId, ws)
+				instances, err := s.state(ctx).InstancesByDeployment(ctx, scope.DeploymentId, ws)
 				if err != nil {
-					return nil, err
+					return nil, hcerr.Externalize(
+						log,
+						err,
+						"failed to get instance by deployment",
+						"deployment_id",
+						scope.DeploymentId,
+					)
 				}
 				instanceLog.Trace("instances loaded for deployment",
 					"instances_len", len(instances))
@@ -256,8 +273,8 @@ func (s *Service) GetLogStream(
 		// Be sure to cleanup all our detritus when done!
 		defer func() {
 			for _, il := range deploymentToInstance {
-				inmemstate.InstanceLogsDelete(il.InstanceLogsId)
-				s.state(ctx).JobCancel(il.JobId, false)
+				inmemstate.InstanceLogsDelete(ctx, il.InstanceLogsId)
+				s.state(ctx).JobCancel(ctx, il.JobId, false)
 			}
 		}()
 
@@ -269,7 +286,7 @@ func (s *Service) GetLogStream(
 			// We filter and only consider successful and created deployments because
 			// that most accurate matches the only scope, so we shouldn't miss anything.
 
-			deployments, err := s.state(ctx).DeploymentList(scope.Application.Application,
+			deployments, err := s.state(ctx).DeploymentList(ctx, scope.Application.Application,
 				serverstate.ListWithPhysicalState(pb.Operation_CREATED),
 				serverstate.ListWithWorkspace(scope.Application.Workspace),
 				serverstate.ListWithStatusFilter(&pb.StatusFilter{
@@ -284,7 +301,11 @@ func (s *Service) GetLogStream(
 				serverstate.ListWithWatchSet(ws),
 			)
 			if err != nil {
-				return nil, err
+				return nil, hcerr.Externalize(
+					log,
+					err,
+					"failed to list successful deployments",
+				)
 			}
 			instanceLog.Trace(
 				"deployments refreshed for application",
@@ -302,7 +323,11 @@ func (s *Service) GetLogStream(
 						instanceLog.Trace("deployment supports log plugin, spawning log plugin instance")
 						inst, jobId, err := s.spawnLogPlugin(srv.Context(), log, dep)
 						if err != nil {
-							return nil, err
+							return nil, hcerr.Externalize(
+								log,
+								err,
+								"failed to launch log plugin for deployment",
+							)
 						}
 						instanceLog.Trace("log plugin spawned", "job_id", jobId)
 
@@ -320,9 +345,15 @@ func (s *Service) GetLogStream(
 					}
 				} else {
 					instanceLog.Trace("tracking instances for deployment", "deployment_id", dep.Id)
-					depInstances, err := s.state(ctx).InstancesByDeployment(dep.Id, ws)
+					depInstances, err := s.state(ctx).InstancesByDeployment(ctx, dep.Id, ws)
 					if err != nil {
-						return nil, err
+						return nil, hcerr.Externalize(
+							log,
+							err,
+							"failed to get instance by deployment",
+							"deployment_id",
+							dep.Id,
+						)
 					}
 
 					for _, i := range depInstances {
