@@ -12,6 +12,7 @@ import (
 	"github.com/hashicorp/waypoint/internal/pkg/graph"
 	"github.com/hashicorp/waypoint/pkg/server"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	serverptypes "github.com/hashicorp/waypoint/pkg/server/ptypes"
 )
 
@@ -24,8 +25,12 @@ func (s *Service) UpsertPipeline(
 	}
 
 	result := req.Pipeline
-	if err := s.state(ctx).PipelinePut(result); err != nil {
-		return nil, err
+	if err := s.state(ctx).PipelinePut(ctx, result); err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error upserting pipeline",
+		)
 	}
 
 	return &pb.UpsertPipelineResponse{Pipeline: result}, nil
@@ -40,16 +45,26 @@ func (s *Service) GetPipeline(
 		return nil, err
 	}
 
-	p, err := s.state(ctx).PipelineGet(req.Pipeline)
+	p, err := s.state(ctx).PipelineGet(ctx, req.Pipeline)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error getting pipeline",
+		)
 	}
 
 	// Get the graph for the steps so we can get the root. We enforce a
 	// single root so the root is always the first step.
 	stepGraph, err := serverptypes.PipelineGraph(p)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error generating pipline graph",
+			"pipeline_id",
+			p.Id,
+		)
 	}
 
 	orderedStep := stepGraph.KahnSort()
@@ -71,9 +86,13 @@ func (s *Service) ListPipelines(
 		return nil, err
 	}
 
-	result, err := s.state(ctx).PipelineList(req.Project)
+	result, err := s.state(ctx).PipelineList(ctx, req.Project)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error listing piplines",
+		)
 	}
 
 	return &pb.ListPipelinesResponse{
@@ -91,9 +110,13 @@ func (s *Service) RunPipeline(
 	}
 
 	// Get the pipeline we should execute
-	pipeline, err := s.state(ctx).PipelineGet(req.Pipeline)
+	pipeline, err := s.state(ctx).PipelineGet(ctx, req.Pipeline)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error getting pipeline",
+		)
 	}
 
 	// Get the graph for the steps so we can get the root. We enforce a
@@ -102,11 +125,15 @@ func (s *Service) RunPipeline(
 		make(map[string]string), nil, pipeline)
 	if err != nil {
 		log.Error("server failed to build full pipeline graph to determine cycles", "err", err)
-		return nil, err
+		return nil, hcerr.Externalize(
+			log,
+			fmt.Errorf("server failed to build full pipeline graph to determine cycles: %w", err),
+			"server failed to build full pipeline graph to determine cycles",
+		)
 	}
 
 	// Initialize a pipeline run
-	if err = s.state(ctx).PipelineRunPut(&pb.PipelineRun{
+	if err = s.state(ctx).PipelineRunPut(ctx, &pb.PipelineRun{
 		Pipeline: &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: pipeline.Id,
@@ -114,19 +141,37 @@ func (s *Service) RunPipeline(
 		},
 		State: pb.PipelineRun_PENDING,
 	}); err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			log,
+			err,
+			"error initializing pipeline run",
+			"pipeline_id",
+			pipeline.Id,
+		)
 	}
 
-	pipelineRun, err := s.state(ctx).PipelineRunGetLatest(pipeline.Id)
+	pipelineRun, err := s.state(ctx).PipelineRunGetLatest(ctx, pipeline.Id)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			log,
+			err,
+			"error getting latest pipeline run",
+			"pipeline_id",
+			pipeline.Id,
+		)
 	}
 
 	// Build out all of the queued job requests for running this pipeline's steps
 	stepJobs, pipelineRun, stepIds, err := s.buildStepJobs(ctx, log, req,
 		make(map[string]interface{}), nodeToStepRef, make(map[string][]string), pipeline, pipelineRun)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			log,
+			err,
+			"error building jobs for pipeline",
+			"pipeline_id",
+			pipeline.Id,
+		)
 	}
 
 	// Get the ordered jobs.
@@ -139,11 +184,21 @@ func (s *Service) RunPipeline(
 		nodeId := v.(string)
 		stepRef, ok := nodeToStepRef.nodeStepRefs[nodeId]
 		if !ok {
-			return nil, status.Errorf(codes.Internal,
-				"could not get pipeline step ref for node id %q", nodeId)
+			return nil, hcerr.Externalize(
+				log,
+				fmt.Errorf("could not get pipeline step ref for node id: %q", nodeId),
+				"error getting pipeline step",
+				"pipeline_id",
+				pipeline.Id,
+			)
 		} else if stepRef == nil {
-			return nil, status.Errorf(codes.Internal,
-				"node id %q returned a nil pipeline step ref", nodeId)
+			return nil, hcerr.Externalize(
+				log,
+				fmt.Errorf("node id %q returned a nil pipeline step ref", nodeId),
+				"error getting pipeline steps reference",
+				"pipeline_id",
+				pipeline.Id,
+			)
 		}
 
 		// get the generated queued job request
@@ -165,13 +220,25 @@ func (s *Service) RunPipeline(
 	}
 
 	pipelineRun.State = pb.PipelineRun_STARTING
-	if err = s.state(ctx).PipelineRunPut(pipelineRun); err != nil {
-		return nil, err
+	if err = s.state(ctx).PipelineRunPut(ctx, pipelineRun); err != nil {
+		return nil, hcerr.Externalize(
+			log,
+			err,
+			"error updating pipeline to starting state",
+			"pipeline_id",
+			pipeline.Id,
+		)
 	}
 
 	// Queue all the jobs atomically
 	if _, err := s.queueJobMulti(ctx, stepJobs); err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			log,
+			err,
+			"error queueing jobs for pipeline",
+			"pipeline_id",
+			pipeline.Id,
+		)
 	}
 
 	return &pb.RunPipelineResponse{
@@ -384,7 +451,7 @@ func (s *Service) buildStepJobs(
 				},
 			}
 		case *pb.Pipeline_Step_Pipeline_:
-			embeddedPipeline, err := s.state(ctx).PipelineGet(o.Pipeline.Ref)
+			embeddedPipeline, err := s.state(ctx).PipelineGet(ctx, o.Pipeline.Ref)
 			if err != nil {
 				return nil, nil, nil, err
 			}
@@ -593,7 +660,7 @@ func (s *Service) pipelineGraphFull(
 		if embedRef, ok := step.Kind.(*pb.Pipeline_Step_Pipeline_); ok {
 			// This is only a "ref" to the pipeline, we have to
 			// look it up here to get the actual steps.
-			embeddedPipeline, err := s.state(ctx).PipelineGet(embedRef.Pipeline.Ref)
+			embeddedPipeline, err := s.state(ctx).PipelineGet(ctx, embedRef.Pipeline.Ref)
 			if err != nil {
 				return nil, nil, err
 			}
