@@ -2,6 +2,7 @@ package singleprocess
 
 import (
 	"context"
+	"fmt"
 	"io"
 	"strings"
 	"time"
@@ -14,7 +15,6 @@ import (
 	"github.com/pkg/errors"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
-	"google.golang.org/protobuf/types/known/emptypb"
 	empty "google.golang.org/protobuf/types/known/emptypb"
 	"google.golang.org/protobuf/types/known/timestamppb"
 
@@ -29,7 +29,7 @@ func (s *Service) ListRunners(
 	ctx context.Context,
 	req *pb.ListRunnersRequest,
 ) (*pb.ListRunnersResponse, error) {
-	runners, err := s.state(ctx).RunnerList()
+	runners, err := s.state(ctx).RunnerList(ctx)
 	if err != nil {
 		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to list runners")
 	}
@@ -41,7 +41,7 @@ func (s *Service) GetRunner(
 	ctx context.Context,
 	req *pb.GetRunnerRequest,
 ) (*pb.Runner, error) {
-	result, err := s.state(ctx).RunnerById(req.RunnerId, nil)
+	result, err := s.state(ctx).RunnerById(ctx, req.RunnerId, nil)
 	if err != nil {
 		return nil, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to get runner", "id", req.RunnerId)
 	}
@@ -53,7 +53,7 @@ func (s *Service) RunnerGetDeploymentConfig(
 	req *pb.RunnerGetDeploymentConfigRequest,
 ) (*pb.RunnerGetDeploymentConfigResponse, error) {
 	// Get our server config
-	serverConfig, err := s.GetServerConfig(ctx, &emptypb.Empty{})
+	serverConfig, err := s.GetServerConfig(ctx, &empty.Empty{})
 	if err != nil {
 		return nil, errors.Wrapf(err, "failed to get server config to populate runner start job server addr")
 	}
@@ -94,11 +94,11 @@ func (s *Service) AdoptRunner(
 	}
 	log := hclog.FromContext(ctx)
 	if req.Adopt {
-		if err = s.state(ctx).RunnerAdopt(req.RunnerId, false); err != nil {
+		if err = s.state(ctx).RunnerAdopt(ctx, req.RunnerId, false); err != nil {
 			return &empty.Empty{}, hcerr.Externalize(log, err, "failed to adopt runner", "id", req.RunnerId)
 		}
 	} else {
-		if err = s.state(ctx).RunnerReject(req.RunnerId); err != nil {
+		if err = s.state(ctx).RunnerReject(ctx, req.RunnerId); err != nil {
 			return &empty.Empty{}, hcerr.Externalize(log, err, "failed to reject runner", "id", req.RunnerId)
 		}
 	}
@@ -114,7 +114,7 @@ func (s *Service) ForgetRunner(
 	if err = serverptypes.ValidateForgetRunnerRequest(req); err != nil {
 		return nil, err
 	}
-	if err = s.state(ctx).RunnerDelete(req.RunnerId); err != nil {
+	if err = s.state(ctx).RunnerDelete(ctx, req.RunnerId); err != nil {
 		return &empty.Empty{}, hcerr.Externalize(hclog.FromContext(ctx), err, "failed to delete runner", "id", req.RunnerId)
 	}
 	return &empty.Empty{}, nil
@@ -190,7 +190,7 @@ func (s *Service) RunnerToken(
 	// Create our record
 	log = log.With("runner_id", record.Id)
 	log.Trace("registering runner")
-	if err := s.state(ctx).RunnerCreate(record); err != nil {
+	if err := s.state(ctx).RunnerCreate(ctx, record); err != nil {
 		return nil, hcerr.Externalize(log, err, "failed to create runner", "id", record.Id)
 	}
 
@@ -198,13 +198,13 @@ func (s *Service) RunnerToken(
 	// if we're never adopted.
 	defer func() {
 		log.Trace("marking runner as offline")
-		if err := s.state(ctx).RunnerOffline(record.Id); err != nil {
+		if err := s.state(ctx).RunnerOffline(ctx, record.Id); err != nil {
 			log.Error("failed to mark runner as offline. This should not happen.", "err", err)
 		}
 	}()
 
 	// Get the runner
-	r, err := s.state(ctx).RunnerById(record.Id, nil)
+	r, err := s.state(ctx).RunnerById(ctx, record.Id, nil)
 	if status.Code(err) == codes.NotFound {
 		err = nil
 		r = nil
@@ -227,7 +227,7 @@ func (s *Service) RunnerToken(
 	for {
 		// Get the runner
 		ws := memdb.NewWatchSet()
-		r, err := s.state(ctx).RunnerById(record.Id, ws)
+		r, err := s.state(ctx).RunnerById(ctx, record.Id, ws)
 		if err != nil {
 			return nil, hcerr.Externalize(log, err, "failed to get runner while waiting for adoption state to change", "id", record.Id)
 		}
@@ -243,12 +243,18 @@ func (s *Service) RunnerToken(
 
 			hash, err := serverptypes.RunnerLabelHash(record.Labels)
 			if err != nil {
-				return nil, err
+				return nil, hcerr.Externalize(log, err, "failed to calculate runner hash", "id", record.Id)
 			}
 
 			encodedId, err := s.encodeId(ctx, record.Id)
 			if err != nil {
-				return nil, errors.Wrapf(err, "failed to encode runner id %s", record.Id)
+				return nil, hcerr.Externalize(
+					log,
+					fmt.Errorf("failed to encode runner id %s", record.Id),
+					"failed to encode runner id",
+					"id",
+					record.Id,
+				)
 			}
 
 			tok, err := s.newToken(ctx,
@@ -269,7 +275,11 @@ func (s *Service) RunnerToken(
 				},
 			)
 			if err != nil {
-				return nil, err
+				return nil, hcerr.Externalize(
+					log,
+					err,
+					"failed to generate new runner token",
+				)
 			}
 
 			return &pb.RunnerTokenResponse{Token: tok}, nil
@@ -278,7 +288,11 @@ func (s *Service) RunnerToken(
 		// Wait for changes
 		log.Trace("runner is not adopted, waiting for state change")
 		if err := ws.WatchCtx(ctx); err != nil {
-			return nil, err
+			return nil, hcerr.Externalize(
+				log,
+				err,
+				"error waiting for runner state changes",
+			)
 		}
 	}
 }
@@ -293,7 +307,11 @@ func (s *Service) RunnerConfig(
 	// Get the request
 	event, err := srv.Recv()
 	if err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"error receiving runner config request",
+		)
 	}
 	req, ok := event.Event.(*pb.RunnerConfigRequest_Open_)
 	if !ok {
@@ -304,27 +322,31 @@ func (s *Service) RunnerConfig(
 
 	// Get our token and reverify that we are adopted.
 	if err := s.runnerVerifyToken(log, ctx, record.Id, record.Labels); err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"error verifying runner token",
+		)
 	}
 
 	// Create our record
 	log = log.With("runner_id", record.Id)
 	log.Trace("registering runner")
-	if err := s.state(ctx).RunnerCreate(record); err != nil {
+	if err := s.state(ctx).RunnerCreate(ctx, record); err != nil {
 		return hcerr.Externalize(log, err, "failed to create runner", "id", record.Id)
 	}
 
 	// Mark the runner as offline if they disconnect from the config stream loop.
 	defer func() {
 		log.Trace("marking runner as offline")
-		if err := s.state(ctx).RunnerOffline(record.Id); err != nil {
+		if err := s.state(ctx).RunnerOffline(ctx, record.Id); err != nil {
 			log.Error("failed to mark runner as offline. This should not happen.", "err", err)
 		}
 	}()
 
 	// If the runner we just registered is explicitly rejected then we
 	// do not allow it to continue, even with a preadoption token.
-	r, err := s.state(ctx).RunnerById(record.Id, nil)
+	r, err := s.state(ctx).RunnerById(ctx, record.Id, nil)
 	if err != nil {
 		return hcerr.Externalize(log, err, "failed to get newly-registered runner", "id", record.Id)
 	}
@@ -333,7 +355,7 @@ func (s *Service) RunnerConfig(
 			"runner is explicitly rejected (unadopted)")
 	}
 	if r.AdoptionState != pb.Runner_ADOPTED {
-		if err := s.state(ctx).RunnerAdopt(record.Id, true); err != nil {
+		if err := s.state(ctx).RunnerAdopt(ctx, record.Id, true); err != nil {
 			return hcerr.Externalize(log, err, "failed to adopt runner", "id", record.Id)
 		}
 	}
@@ -389,7 +411,7 @@ func (s *Service) RunnerConfig(
 		}
 
 		newExpireTime := timestamppb.New(time.Now().Add(dur))
-		if err := s.state(ctx).JobUpdateExpiry(job.Id, newExpireTime); err != nil {
+		if err := s.state(ctx).JobUpdateExpiry(ctx, job.Id, newExpireTime); err != nil {
 			return hcerr.Externalize(log, err, "failed to update job expiry time after runner accepted job", "id", job.Id)
 		}
 
@@ -422,7 +444,7 @@ func (s *Service) RunnerConfig(
 			configReq.Labels = job.Labels
 		}
 
-		vars, err := s.state(ctx).ConfigGetWatch(configReq, ws)
+		vars, err := s.state(ctx).ConfigGetWatch(ctx, configReq, ws)
 		if err != nil {
 			return hcerr.Externalize(log, err, "failed to get configuration variables")
 		}
@@ -450,7 +472,7 @@ func (s *Service) RunnerConfig(
 					Application: job.Application,
 				}
 			}
-			sources, err := s.state(ctx).ConfigSourceGetWatch(getConfigSourceRequest, ws)
+			sources, err := s.state(ctx).ConfigSourceGetWatch(ctx, getConfigSourceRequest, ws)
 			if err != nil {
 				return hcerr.Externalize(log, err, "failed to get the configuration for a dynamic source plugin")
 			}
@@ -462,7 +484,11 @@ func (s *Service) RunnerConfig(
 		if err := srv.Send(&pb.RunnerConfigResponse{
 			Config: config,
 		}); err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"error sending runner config response",
+			)
 		}
 
 		// Nil out the stuff we used so that if we're waiting awhile we can GC
@@ -470,7 +496,11 @@ func (s *Service) RunnerConfig(
 
 		// Wait for any changes
 		if err := ws.WatchCtx(ctx); err != nil {
-			return err
+			return hcerr.Externalize(
+				log,
+				err,
+				"error waiting for runner config state changes",
+			)
 		}
 	}
 }
@@ -485,34 +515,49 @@ func (s *Service) RunnerJobStream(
 	// Receive our opening message so we can determine the runner ID.
 	req, err := server.Recv()
 	if err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"failed to receive first message for RunnerJobStrem",
+		)
 	}
 	reqEvent, ok := req.Event.(*pb.RunnerJobStreamRequest_Request_)
 	if !ok {
-		return status.Errorf(codes.FailedPrecondition,
-			"first message must be a Request event")
+		return hcerr.Externalize(
+			log,
+			status.Errorf(codes.FailedPrecondition,
+				"first message must be a Request event"),
+			"first message to RunnerJobStream must be a Request event",
+		)
 	}
-	log = log.With("runner_id", reqEvent.Request.RunnerId)
 
 	// Get the runner to validate it is registered
 	runnerId := reqEvent.Request.RunnerId
 
-	runner, err := s.state(ctx).RunnerById(runnerId, nil)
+	runner, err := s.state(ctx).RunnerById(ctx, runnerId, nil)
 	if err != nil {
 		return hcerr.Externalize(log, err, "failed to get this runner", "id", runnerId)
 	}
-	log.With("runner-id", runner.Id)
+	log = log.With("runner_id", reqEvent.Request.RunnerId)
 
 	// The runner must be adopted to get a job.
 	if runner.AdoptionState != pb.Runner_ADOPTED &&
 		runner.AdoptionState != pb.Runner_PREADOPTED {
-		return status.Errorf(codes.FailedPrecondition,
-			"runner must be adopted prior to requesting jobs")
+		return hcerr.Externalize(
+			log,
+			status.Errorf(codes.FailedPrecondition,
+				"runner must be adopted prior to requesting jobs"),
+			"runner must be adopted prior to requesting jobs",
+		)
 	}
 
 	// Verify our token matches the request
 	if err := s.runnerVerifyToken(log, ctx, runner.Id, runner.Labels); err != nil {
-		return err
+		return hcerr.Externalize(
+			log,
+			err,
+			"runner token verification failed",
+		)
 	}
 
 	// Get the job for this runner. If this is a reattach, we lookup
@@ -524,22 +569,34 @@ func (s *Service) RunnerJobStream(
 		reattach = true
 
 		log.Info("runner reattaching to an existing job", "job_id", jobId)
-		job, err = s.state(ctx).JobById(jobId, nil)
+		job, err = s.state(ctx).JobById(ctx, jobId, nil)
 		if err != nil {
 			return hcerr.Externalize(log, err, "failed to get job", "id", jobId)
 		}
 
 		// If the job is not found, that is an error.
 		if job == nil {
-			return status.Errorf(codes.InvalidArgument,
-				"reattach job ID does not exist")
+			return hcerr.Externalize(
+				log,
+				status.Errorf(codes.InvalidArgument,
+					"reattach job ID does not exist"),
+				"reattach job ID does not exist",
+				"id",
+				jobId,
+			)
 		}
 
 		// The runner reattaching must be the assigned runner.
 		assigned := job.Job.AssignedRunner
 		if assigned == nil || assigned.Id != runner.Id {
-			return status.Errorf(codes.InvalidArgument,
-				"reattach job is not assigned to this runner")
+			return hcerr.Externalize(
+				log,
+				status.Errorf(codes.InvalidArgument,
+					"reattach job is not assigned to this runner"),
+				"reattach job is not assigned to this runner",
+				"id",
+				jobId,
+			)
 		}
 
 		// NOTE(mitchellh): things we should check in the future:
@@ -551,7 +608,7 @@ func (s *Service) RunnerJobStream(
 		log.Info("waiting for job assignment")
 		job, err = s.state(ctx).JobAssignForRunner(ctx, runner)
 		if err != nil {
-			return hcerr.Externalize(log, err, "failed to get job assignment for runner", "id", runnerId)
+			return hcerr.Externalize(log, err, "failed to get job assignment for runner")
 		}
 		jobId = job.Id
 	}
@@ -561,7 +618,7 @@ func (s *Service) RunnerJobStream(
 	log = log.With("job_id", jobId)
 
 	// Load config sourcers to send along with the job assignment
-	cfgSrcs, err := s.state(ctx).ConfigSourceGetWatch(&pb.GetConfigSourceRequest{
+	cfgSrcs, err := s.state(ctx).ConfigSourceGetWatch(ctx, &pb.GetConfigSourceRequest{
 		Scope: &pb.GetConfigSourceRequest_Application{
 			Application: job.Application,
 		},
@@ -629,7 +686,7 @@ func (s *Service) RunnerJobStream(
 	if !reattach {
 		// Send the ack OR nack, based on the value of +ack+.
 		var ackerr error
-		job, ackerr = s.state(ctx).JobAck(job.Id, ack)
+		job, ackerr = s.state(ctx).JobAck(ctx, jobId, ack)
 		if ackerr != nil {
 			// If this fails, we just log, there is nothing more we can do.
 			log.Warn("job ack failed", "outer_error", err, "error", ackerr)
@@ -652,14 +709,14 @@ func (s *Service) RunnerJobStream(
 		// we cancel the job.
 		if !ack {
 			log.Warn("reattach job was nacked, force cancelling")
-			err = s.state(ctx).JobCancel(jobId, true)
+			err = s.state(ctx).JobCancel(ctx, jobId, true)
 		}
 	}
 
 	// If we have an error, return that. We also return if we didn't ack for
 	// any reason. This error can be set at any point since job assignment.
 	if err != nil {
-		return hcerr.Externalize(log, err, "failed to ack the job or the job was cancelled", "id", runnerId, "job", jobId)
+		return hcerr.Externalize(log, err, "failed to ack the job or the job was cancelled", "id", jobId)
 	}
 	if !ack {
 		// If runners don't ack the job, this means close the stream
@@ -670,7 +727,7 @@ func (s *Service) RunnerJobStream(
 	if s.logStreamProvider != nil {
 		logStreamWriter, err = s.logStreamProvider.StartWriter(ctx, log, s.state(ctx), job)
 		if err != nil {
-			return errors.Wrapf(err, "failed to start a log writer to handle jog logs")
+			return hcerr.Externalize(log, err, "failed to start a log writer to handle jog logs")
 		}
 	}
 
@@ -686,7 +743,7 @@ func (s *Service) RunnerJobStream(
 	go func() {
 		for {
 			ws := memdb.NewWatchSet()
-			job, err = s.state(ctx).JobById(jobId, ws)
+			job, err = s.state(ctx).JobById(ctx, jobId, ws)
 			if err != nil {
 				errCh <- errors.Wrapf(err, "error getting job by id from state %q", jobId)
 				return
@@ -706,7 +763,7 @@ func (s *Service) RunnerJobStream(
 			// Wait for the job to update
 			if err := ws.WatchCtx(ctx); err != nil {
 				if ctx.Err() == nil {
-					errCh <- err
+					errCh <- errors.Wrapf(err, "error on context while waiting for job %q", jobId)
 				}
 
 				return
@@ -733,7 +790,7 @@ func (s *Service) RunnerJobStream(
 				// For any other error, we send the error along and exit the
 				// read loop. The sent error will be picked up and sent back
 				// as a result to the client.
-				errCh <- err
+				errCh <- errors.Wrapf(err, "failed receiving from runner for job %q", jobId)
 				return
 			}
 			log.Trace("event received", "event", req.Event)
@@ -768,8 +825,7 @@ func (s *Service) RunnerJobStream(
 				select {
 				case req := <-eventCh:
 					if err := s.handleJobStreamRequest(log, job, server, req, logStreamWriter); err != nil {
-						log.Error("error handling job stream request during drain", "err", err, "req", req)
-						return err
+						return hcerr.Externalize(log, err, "error handling job stream request during drain", "req", req)
 					}
 				default:
 					return nil
@@ -777,8 +833,7 @@ func (s *Service) RunnerJobStream(
 			}
 
 		case err := <-errCh:
-			log.Error("err from err channel", "err", err)
-			return err
+			return hcerr.Externalize(log, err, "err from err channel")
 
 		case req := <-eventCh:
 			if job == nil {
@@ -793,7 +848,7 @@ func (s *Service) RunnerJobStream(
 					// Attempt to complete job with original jobId so that the original
 					// job Id isn't left hanging in a Running state. We also send through
 					// the error to give to the job details for why it's Errored.
-					if err := s.state(ctx).JobComplete(jobId, nil, err); err != nil {
+					if err := s.state(ctx).JobComplete(ctx, jobId, nil, err); err != nil {
 						return hcerr.Externalize(log, err,
 							"failed to complete job while failing to process job event",
 							"id", jobId,
@@ -805,8 +860,7 @@ func (s *Service) RunnerJobStream(
 				}
 			}
 			if err := s.handleJobStreamRequest(log, job, server, req, logStreamWriter); err != nil {
-				log.Error("error handling job stream request", "err", err, "req", req)
-				return err
+				return hcerr.Externalize(log, err, "error handling job stream request", "req", req)
 			}
 
 		case job := <-jobCh:
@@ -834,8 +888,7 @@ func (s *Service) RunnerJobStream(
 					},
 				})
 				if err != nil {
-					log.Error("error sending job cancel event to runner", "err", err)
-					return err
+					return hcerr.Externalize(log, err, "error sending job cancel event to runner")
 				}
 
 				// On force we exit immediately.
@@ -861,30 +914,53 @@ func (s *Service) handleJobStreamRequest(
 	log.Trace("event received", "event", req.Event)
 	switch event := req.Event.(type) {
 	case *pb.RunnerJobStreamRequest_Complete_:
-		if err := s.state(ctx).JobComplete(job.Id, event.Complete.Result, nil); err != nil {
+		if event.Complete == nil {
+			log.Error("event.Complete was not filled when we expected it to be", "id", job.Id, "event", req.Event)
+			return hcerr.Externalize(log, fmt.Errorf("failed to complete job"), "failed to complete job", "id", job.Id)
+		}
+		if err := s.state(ctx).JobComplete(ctx, job.Id, event.Complete.Result, nil); err != nil {
 			return hcerr.Externalize(log, err, "failed to complete job", "id", job.Id)
 		}
 	case *pb.RunnerJobStreamRequest_Error_:
-		if err := s.state(ctx).JobComplete(job.Id, nil, status.FromProto(event.Error.Error).Err()); err != nil {
+		var remoteError error
+
+		if event.Error != nil {
+			remoteError = status.FromProto(event.Error.Error).Err()
+		} else {
+			log.Warn("job error did not include error description")
+			remoteError = status.New(codes.Unknown, "remote error not correctly reported").Err()
+		}
+
+		if err := s.state(ctx).JobComplete(ctx, job.Id, nil, remoteError); err != nil {
 			return hcerr.Externalize(log, err, "failed to complete job", "id", job.Id)
 		}
 	case *pb.RunnerJobStreamRequest_Heartbeat_:
-		if err := s.state(ctx).JobHeartbeat(job.Id); err != nil {
+		if err := s.state(ctx).JobHeartbeat(ctx, job.Id); err != nil {
 			return hcerr.Externalize(log, err, "job heartbeat failed", "id", job.Id)
 		}
 	case *pb.RunnerJobStreamRequest_Download:
-		if err := s.state(ctx).JobUpdateRef(job.Id, event.Download.DataSourceRef); err != nil {
+		if event.Download == nil {
+			log.Warn("invalid download event detected")
+			return status.Error(codes.InvalidArgument, "download information missing")
+		}
+
+		if err := s.state(ctx).JobUpdateRef(ctx, job.Id, event.Download.DataSourceRef); err != nil {
 			return hcerr.Externalize(log, err, "failed to update the job reference", "id", job.Id)
 		}
 
-		if err := s.state(ctx).ProjectUpdateDataRef(&pb.Ref_Project{
+		if err := s.state(ctx).ProjectUpdateDataRef(ctx, &pb.Ref_Project{
 			Project: job.Application.Project,
 		}, job.Workspace, event.Download.DataSourceRef); err != nil {
 			return hcerr.Externalize(log, err, "failed to update the project", "project", job.Application.Project)
 		}
 
 	case *pb.RunnerJobStreamRequest_ConfigLoad_:
-		if err := s.state(ctx).JobUpdate(job.Id, func(jobpb *pb.Job) error {
+		if event.ConfigLoad == nil {
+			log.Warn("invalid configload event detected")
+			return status.Error(codes.InvalidArgument, "config information missing")
+		}
+
+		if err := s.state(ctx).JobUpdate(ctx, job.Id, func(jobpb *pb.Job) error {
 			jobpb.Config = event.ConfigLoad.Config
 			return nil
 		}); err != nil {
@@ -892,7 +968,12 @@ func (s *Service) handleJobStreamRequest(
 		}
 
 	case *pb.RunnerJobStreamRequest_VariableValuesSet_:
-		if err := s.state(ctx).JobUpdate(job.Id, func(jobpb *pb.Job) error {
+		if event.VariableValuesSet == nil {
+			log.Warn("invalid variableset event detected")
+			return status.Error(codes.InvalidArgument, "variableset information missing")
+		}
+
+		if err := s.state(ctx).JobUpdate(ctx, job.Id, func(jobpb *pb.Job) error {
 			jobpb.VariableFinalValues = event.VariableValuesSet.FinalValues
 			return nil
 		}); err != nil {
