@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"context"
 	"testing"
 	"time"
 
@@ -16,10 +17,12 @@ func init() {
 	tests["deployment"] = []testFunc{
 		TestDeployment,
 		TestDeploymentListFilter,
+		TestDeploymentGet,
 	}
 }
 
 func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
+	ctx := context.Background()
 	t.Run("CRUD operations", func(t *testing.T) {
 		require := require.New(t)
 
@@ -28,13 +31,13 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "foo"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Has no apps
 		{
-			resp, err := s.ProjectGet(ref)
+			resp, err := s.ProjectGet(ctx, ref)
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Empty(resp.Applications)
@@ -50,7 +53,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Add
-		err := s.DeploymentPut(false, serverptypes.TestDeployment(t, &pb.Deployment{
+		err := s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
 			Id:          "d1",
 			Application: app,
 			Workspace:   ws,
@@ -63,7 +66,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Can read
 		{
-			resp, err := s.DeploymentGet(&pb.Ref_Operation{
+			resp, err := s.DeploymentGet(ctx, &pb.Ref_Operation{
 				Target: &pb.Ref_Operation_Id{
 					Id: "d1",
 				},
@@ -74,14 +77,14 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Can read latest
 		{
-			resp, err := s.DeploymentLatest(app, &pb.Ref_Workspace{Workspace: "default"})
+			resp, err := s.DeploymentLatest(ctx, app, &pb.Ref_Workspace{Workspace: "default"})
 			require.NoError(err)
 			require.NotNil(resp)
 		}
 
 		// Update
 		ts := timestamppb.Now()
-		err = s.DeploymentPut(true, serverptypes.TestDeployment(t, &pb.Deployment{
+		err = s.DeploymentPut(ctx, true, serverptypes.TestDeployment(t, &pb.Deployment{
 			Id:          "d1",
 			Application: app,
 			Workspace:   ws,
@@ -94,7 +97,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.DeploymentGet(&pb.Ref_Operation{
+			resp, err := s.DeploymentGet(ctx, &pb.Ref_Operation{
 				Target: &pb.Ref_Operation_Id{
 					Id: "d1",
 				},
@@ -107,7 +110,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Add another and see Latset change
 		// Add
-		err = s.DeploymentPut(false, serverptypes.TestDeployment(t, &pb.Deployment{
+		err = s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
 			Id:          "d2",
 			Application: app,
 			Workspace:   ws,
@@ -120,14 +123,14 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.DeploymentLatest(app, &pb.Ref_Workspace{Workspace: "default"})
+			resp, err := s.DeploymentLatest(ctx, app, &pb.Ref_Workspace{Workspace: "default"})
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Equal("d2", resp.Id)
 		}
 
 		{
-			resp, err := s.DeploymentList(app)
+			resp, err := s.DeploymentList(ctx, app)
 			require.NoError(err)
 
 			require.Len(resp, 2)
@@ -150,7 +153,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 		*/
 
 		{
-			resp, err := s.DeploymentList(app, serverstate.ListWithOrder(&pb.OperationOrder{
+			resp, err := s.DeploymentList(ctx, app, serverstate.ListWithOrder(&pb.OperationOrder{
 				Order: pb.OperationOrder_START_TIME,
 				Desc:  true,
 				Limit: 1,
@@ -162,7 +165,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 			require.Equal("d2", resp[0].Id)
 		}
 
-		err = s.DeploymentPut(false, serverptypes.TestDeployment(t, &pb.Deployment{
+		err = s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
 			Id:          "d3",
 			Application: app,
 			Workspace:   ws,
@@ -174,14 +177,14 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.DeploymentList(app)
+			resp, err := s.DeploymentList(ctx, app)
 			require.NoError(err)
 
 			require.Len(resp, 3)
 		}
 
 		{
-			resp, err := s.DeploymentList(app,
+			resp, err := s.DeploymentList(ctx, app,
 				serverstate.ListWithOrder(&pb.OperationOrder{
 					Order: pb.OperationOrder_START_TIME,
 					Desc:  true,
@@ -203,7 +206,7 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 			require.Equal("d3", resp[0].Id)
 		}
 		{
-			resp, err := s.DeploymentList(app,
+			resp, err := s.DeploymentList(ctx, app,
 				serverstate.ListWithOrder(&pb.OperationOrder{
 					Order: pb.OperationOrder_START_TIME,
 					Desc:  true,
@@ -236,7 +239,125 @@ func TestDeployment(t *testing.T, factory Factory, restartF RestartFactory) {
 	})
 }
 
+func TestDeploymentGet(t *testing.T, factory Factory, restartF RestartFactory) {
+	ctx := context.Background()
+	require := require.New(t)
+
+	s := factory(t)
+	defer s.Close()
+
+	// Setup projects with apps
+
+	proj1 := &pb.Ref_Project{Project: "p1"}
+	app1 := &pb.Ref_Application{
+		Application: "a1",
+		Project:     proj1.Project,
+	}
+	require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
+		Name: proj1.Project,
+	})))
+
+	_, err := s.AppPut(ctx, serverptypes.TestApplication(t, &pb.Application{
+		Name:    app1.Application,
+		Project: proj1,
+	}))
+	require.NoError(err)
+
+	proj2 := &pb.Ref_Project{Project: "p2"}
+	app2 := &pb.Ref_Application{
+		Application: "a2",
+		Project:     proj2.Project,
+	}
+	require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
+		Name: proj2.Project,
+	})))
+
+	_, err = s.AppPut(ctx, serverptypes.TestApplication(t, &pb.Application{
+		Name:    app2.Application,
+		Project: proj2,
+	}))
+	require.NoError(err)
+
+	ws := &pb.Ref_Workspace{
+		Workspace: "default",
+	}
+
+	// Add deployments
+	err = s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
+		Id:          "d1",
+		Application: app1,
+		Workspace:   ws,
+		Status: &pb.Status{
+			State:     pb.Status_SUCCESS,
+			StartTime: timestamppb.Now(),
+		},
+	}))
+	require.NoError(err)
+
+	err = s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
+		Id:          "d2",
+		Application: app2,
+		Workspace:   ws,
+		Status: &pb.Status{
+			State:     pb.Status_SUCCESS,
+			StartTime: timestamppb.Now(),
+		},
+	}))
+	require.NoError(err)
+
+	// Can read proj1 by id and sequence
+	{
+		idResp, err := s.DeploymentGet(ctx, &pb.Ref_Operation{
+			Target: &pb.Ref_Operation_Id{
+				Id: "d1",
+			},
+		})
+		require.NoError(err)
+		require.NotNil(idResp)
+		require.Equal(idResp.Id, "d1")
+
+		seqResp, err := s.DeploymentGet(ctx, &pb.Ref_Operation{
+			Target: &pb.Ref_Operation_Sequence{
+				Sequence: &pb.Ref_OperationSeq{
+					Application: app1,
+					Number:      idResp.Sequence,
+				},
+			},
+		})
+		require.NoError(err)
+		require.NotNil(seqResp)
+		require.Equal(seqResp.Id, "d1")
+		require.Equal(seqResp.Sequence, idResp.Sequence)
+	}
+
+	// Can read proj2 by id and sequence
+	{
+		idResp, err := s.DeploymentGet(ctx, &pb.Ref_Operation{
+			Target: &pb.Ref_Operation_Id{
+				Id: "d2",
+			},
+		})
+		require.NoError(err)
+		require.NotNil(idResp)
+		require.Equal(idResp.Id, "d2")
+
+		seqResp, err := s.DeploymentGet(ctx, &pb.Ref_Operation{
+			Target: &pb.Ref_Operation_Sequence{
+				Sequence: &pb.Ref_OperationSeq{
+					Application: app2,
+					Number:      idResp.Sequence,
+				},
+			},
+		})
+		require.NoError(err)
+		require.NotNil(seqResp)
+		require.Equal(seqResp.Id, "d2")
+		require.Equal(seqResp.Sequence, idResp.Sequence)
+	}
+
+}
 func TestDeploymentListFilter(t *testing.T, f Factory, rf RestartFactory) {
+	ctx := context.Background()
 	require := require.New(t)
 
 	s := f(t)
@@ -244,7 +365,7 @@ func TestDeploymentListFilter(t *testing.T, f Factory, rf RestartFactory) {
 
 	// Write project
 	ref := &pb.Ref_Project{Project: "foo"}
-	require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+	require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 		Name: ref.Project,
 	})))
 
@@ -259,7 +380,7 @@ func TestDeploymentListFilter(t *testing.T, f Factory, rf RestartFactory) {
 
 	// Add a destroyed deployment
 	require.NoError(
-		s.DeploymentPut(false, serverptypes.TestDeployment(t, &pb.Deployment{
+		s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
 			Id:          "destroyed",
 			Application: app,
 			Workspace:   ws,
@@ -271,7 +392,7 @@ func TestDeploymentListFilter(t *testing.T, f Factory, rf RestartFactory) {
 	)
 
 	require.NoError(
-		s.DeploymentPut(false, serverptypes.TestDeployment(t, &pb.Deployment{
+		s.DeploymentPut(ctx, false, serverptypes.TestDeployment(t, &pb.Deployment{
 			Id:          "created",
 			Application: app,
 			Workspace:   ws,
@@ -282,17 +403,17 @@ func TestDeploymentListFilter(t *testing.T, f Factory, rf RestartFactory) {
 		})),
 	)
 
-	resp, err := s.DeploymentList(app, serverstate.ListWithPhysicalState(pb.Operation_CREATED))
+	resp, err := s.DeploymentList(ctx, app, serverstate.ListWithPhysicalState(pb.Operation_CREATED))
 	require.NoError(err)
 	require.Len(resp, 1)
 	require.Equal("created", resp[0].Id)
 
-	resp, err = s.DeploymentList(app, serverstate.ListWithPhysicalState(pb.Operation_DESTROYED))
+	resp, err = s.DeploymentList(ctx, app, serverstate.ListWithPhysicalState(pb.Operation_DESTROYED))
 	require.NoError(err)
 	require.Len(resp, 1)
 	require.Equal("destroyed", resp[0].Id)
 
-	resp, err = s.DeploymentList(app, serverstate.ListWithPhysicalState(pb.Operation_PENDING))
+	resp, err = s.DeploymentList(ctx, app, serverstate.ListWithPhysicalState(pb.Operation_PENDING))
 	require.NoError(err)
 	require.Len(resp, 0)
 }
