@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"context"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -19,6 +20,7 @@ func init() {
 }
 
 func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
+	ctx := context.Background()
 	t.Run("Put and Get", func(t *testing.T) {
 		require := require.New(t)
 
@@ -27,22 +29,22 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err) // no job id set
 
 		// Set again, should overwrite and not error
-		err = s.PipelinePut(p)
+		err = s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Get exact by id
 		{
-			resp, err := s.PipelineGet(&pb.Ref_Pipeline{
+			resp, err := s.PipelineGet(ctx, &pb.Ref_Pipeline{
 				Ref: &pb.Ref_Pipeline_Id{
 					Id: p.Id,
 				},
@@ -52,7 +54,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 		}
 
 		// Delete
-		require.NoError(s.PipelineDelete(&pb.Ref_Pipeline{
+		require.NoError(s.PipelineDelete(ctx, &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: p.Id,
 			},
@@ -67,14 +69,14 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set
 		p := ptypes.TestPipeline(t, nil)
 		p.Steps = nil
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.Error(err)
 		require.Equal(codes.FailedPrecondition, status.Code(err))
 	})
@@ -87,7 +89,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
@@ -103,7 +105,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				DependsOn: []string{"C"},
 			},
 		}
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.Error(err)
 		require.Equal(codes.FailedPrecondition, status.Code(err))
 	})
@@ -116,7 +118,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
@@ -135,7 +137,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				DependsOn: []string{"A"},
 			},
 		}
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.Error(err)
 		require.Equal(codes.FailedPrecondition, status.Code(err))
 	})
@@ -148,7 +150,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
@@ -163,7 +165,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				DependsOn: []string{"C"},
 			},
 		}
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.Error(err)
 		require.Equal(codes.FailedPrecondition, status.Code(err))
 	})
@@ -176,13 +178,13 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set a few pipelines
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Update the pipeline
@@ -196,13 +198,13 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 			},
 		}
 		p.Id = ""
-		err = s.PipelinePut(p)
+		err = s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Should only be 1 pipeline
 		// List should return one pipeline
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -220,13 +222,13 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set a few pipelines
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Update the pipeline
@@ -241,13 +243,13 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 		}
 		p.Id = "test"
 
-		err = s.PipelinePut(p)
+		err = s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Should only be 1 pipeline
 		// List should return one pipeline
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -265,13 +267,13 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set a few pipelines
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Update the pipeline
@@ -287,12 +289,12 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 		p.Id = "two"
 		p.Name = "two"
 
-		err = s.PipelinePut(p)
+		err = s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Should only be 2 pipelines
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -312,12 +314,12 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				},
 			},
 		})
-		err = s.PipelinePut(p2)
+		err = s.PipelinePut(ctx, p2)
 		require.NoError(err)
 
 		// Should be three
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -334,13 +336,13 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set a few pipelines
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Another one
@@ -353,12 +355,12 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				},
 			},
 		})
-		err = s.PipelinePut(p2)
+		err = s.PipelinePut(ctx, p2)
 		require.NoError(err)
 
 		// Write project
 		pref := &pb.Ref_Project{Project: "nintendo"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: pref.Project,
 		})))
 
@@ -372,12 +374,12 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				},
 			},
 		})
-		err = s.PipelinePut(p3)
+		err = s.PipelinePut(ctx, p3)
 		require.NoError(err)
 
 		// Get pipeline by Owner Ref
 		{
-			resp, err := s.PipelineGet(&pb.Ref_Pipeline{
+			resp, err := s.PipelineGet(ctx, &pb.Ref_Pipeline{
 				Ref: &pb.Ref_Pipeline_Owner{
 					Owner: &pb.Ref_PipelineOwner{Project: &pb.Ref_Project{Project: "project"}, PipelineName: "mario"},
 				},
@@ -390,7 +392,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Get pipeline by Owner Ref
 		{
-			resp, err := s.PipelineGet(&pb.Ref_Pipeline{
+			resp, err := s.PipelineGet(ctx, &pb.Ref_Pipeline{
 				Ref: &pb.Ref_Pipeline_Owner{
 					Owner: &pb.Ref_PipelineOwner{Project: &pb.Ref_Project{Project: "nintendo"}, PipelineName: "mario"},
 				},
@@ -410,18 +412,18 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Get pipeline by Owner Ref should be nothing
 		{
-			resp, err := s.PipelineGet(&pb.Ref_Pipeline{
+			resp, err := s.PipelineGet(ctx, &pb.Ref_Pipeline{
 				Ref: &pb.Ref_Pipeline_Owner{
 					Owner: &pb.Ref_PipelineOwner{Project: &pb.Ref_Project{Project: "nope"}, PipelineName: "nope"},
 				},
@@ -440,18 +442,18 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// List should return one pipeline
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -469,7 +471,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				},
 			},
 		})
-		err = s.PipelinePut(p2)
+		err = s.PipelinePut(ctx, p2)
 		require.NoError(err)
 
 		// a third
@@ -482,12 +484,12 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				},
 			},
 		})
-		err = s.PipelinePut(p3)
+		err = s.PipelinePut(ctx, p3)
 		require.NoError(err)
 
 		// List should return three pipelines
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -497,7 +499,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		pref := &pb.Ref_Project{Project: "not-our-project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: pref.Project,
 		})))
 
@@ -511,12 +513,12 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				},
 			},
 		})
-		err = s.PipelinePut(p4)
+		err = s.PipelinePut(ctx, p4)
 		require.NoError(err)
 
 		// List should still return three pipelines
 		{
-			resp, err := s.PipelineList(&pb.Ref_Project{
+			resp, err := s.PipelineList(ctx, &pb.Ref_Project{
 				Project: "project",
 			})
 			require.NoError(err)
@@ -533,17 +535,17 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "project"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Set
 		p := ptypes.TestPipeline(t, nil)
-		err := s.PipelinePut(p)
+		err := s.PipelinePut(ctx, p)
 		require.NoError(err)
 
 		// Get exact by id
-		resp, err := s.PipelineGet(&pb.Ref_Pipeline{
+		resp, err := s.PipelineGet(ctx, &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: p.Id,
 			},
@@ -559,11 +561,11 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 		}
 
 		// Put to update
-		err = s.PipelinePut(resp)
+		err = s.PipelinePut(ctx, resp)
 		require.NoError(err) // no job id set
 
 		// Get exact by id and repeat the check
-		resp, err = s.PipelineGet(&pb.Ref_Pipeline{
+		resp, err = s.PipelineGet(ctx, &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: p.Id,
 			},
@@ -589,11 +591,11 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 				Workspace: &pb.Ref_Workspace{Workspace: "staging"},
 			},
 		})
-		err = s.PipelinePut(updatedPipe)
+		err = s.PipelinePut(ctx, updatedPipe)
 		require.NoError(err)
 
 		// Get exact by id and repeat the check
-		resp, err = s.PipelineGet(&pb.Ref_Pipeline{
+		resp, err = s.PipelineGet(ctx, &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: p.Id, // intentionally using old ID
 			},
@@ -612,7 +614,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 		}
 
 		// Delete
-		require.NoError(s.PipelineDelete(&pb.Ref_Pipeline{
+		require.NoError(s.PipelineDelete(ctx, &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: p.Id,
 			},
@@ -621,7 +623,7 @@ func TestPipeline(t *testing.T, factory Factory, _ RestartFactory) {
 		// Verify delete with other pipe reference.
 		// For reasons unknown, the response returned here is "empty" of any
 		// values but not actually nil.
-		_, err = s.PipelineGet(&pb.Ref_Pipeline{
+		_, err = s.PipelineGet(ctx, &pb.Ref_Pipeline{
 			Ref: &pb.Ref_Pipeline_Id{
 				Id: updatedPipe.Id,
 			},
