@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"context"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -13,15 +14,16 @@ func init() {
 }
 
 func TestServerURLToken(t *testing.T, factory Factory, restartF RestartFactory) {
+	ctx := context.Background()
 	t.Run("set and get", func(t *testing.T) {
 		require := require.New(t)
 
 		s := factory(t)
 		defer s.Close()
 
-		require.NoError(s.ServerURLTokenSet("foo"))
+		require.NoError(s.ServerURLTokenSet(ctx, "foo"))
 
-		str, err := s.ServerURLTokenGet()
+		str, err := s.ServerURLTokenGet(ctx)
 		require.NoError(err)
 		require.Equal("foo", str)
 
