@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"context"
 	"testing"
 	"time"
 
@@ -19,6 +20,7 @@ func init() {
 }
 
 func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
+	ctx := context.Background()
 	t.Run("CRUD operations", func(t *testing.T) {
 		require := require.New(t)
 
@@ -27,13 +29,13 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "foo"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Has no apps
 		{
-			resp, err := s.ProjectGet(ref)
+			resp, err := s.ProjectGet(ctx, ref)
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Empty(resp.Applications)
@@ -49,7 +51,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Add
-		err := s.StatusReportPut(false, serverptypes.TestStatusReport(t, &pb.StatusReport{
+		err := s.StatusReportPut(ctx, false, serverptypes.TestStatusReport(t, &pb.StatusReport{
 			Id:          "d1",
 			Application: app,
 			Workspace:   ws,
@@ -62,7 +64,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Can read
 		{
-			resp, err := s.StatusReportGet(&pb.Ref_Operation{
+			resp, err := s.StatusReportGet(ctx, &pb.Ref_Operation{
 				Target: &pb.Ref_Operation_Id{
 					Id: "d1",
 				},
@@ -73,14 +75,14 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Can read latest
 		{
-			resp, err := s.StatusReportLatest(app, &pb.Ref_Workspace{Workspace: "default"}, nil)
+			resp, err := s.StatusReportLatest(ctx, app, &pb.Ref_Workspace{Workspace: "default"}, nil)
 			require.NoError(err)
 			require.NotNil(resp)
 		}
 
 		// Update
 		ts := timestamppb.Now()
-		err = s.StatusReportPut(true, serverptypes.TestStatusReport(t, &pb.StatusReport{
+		err = s.StatusReportPut(ctx, true, serverptypes.TestStatusReport(t, &pb.StatusReport{
 			Id:          "d1",
 			Application: app,
 			Workspace:   ws,
@@ -93,7 +95,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.StatusReportGet(&pb.Ref_Operation{
+			resp, err := s.StatusReportGet(ctx, &pb.Ref_Operation{
 				Target: &pb.Ref_Operation_Id{
 					Id: "d1",
 				},
@@ -105,7 +107,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Add another and see Latest change
-		err = s.StatusReportPut(false, serverptypes.TestStatusReport(t, &pb.StatusReport{
+		err = s.StatusReportPut(ctx, false, serverptypes.TestStatusReport(t, &pb.StatusReport{
 			Id:          "d2",
 			Application: app,
 			Workspace:   ws,
@@ -118,14 +120,14 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.StatusReportLatest(app, &pb.Ref_Workspace{Workspace: "default"}, nil)
+			resp, err := s.StatusReportLatest(ctx, app, &pb.Ref_Workspace{Workspace: "default"}, nil)
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Equal("d2", resp.Id)
 		}
 
 		{
-			resp, err := s.StatusReportList(app)
+			resp, err := s.StatusReportList(ctx, app)
 			require.NoError(err)
 
 			require.Len(resp, 2)
@@ -148,7 +150,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 		*/
 
 		{
-			resp, err := s.StatusReportList(app, serverstate.ListWithOrder(&pb.OperationOrder{
+			resp, err := s.StatusReportList(ctx, app, serverstate.ListWithOrder(&pb.OperationOrder{
 				Order: pb.OperationOrder_START_TIME,
 				Desc:  true,
 				Limit: 1,
@@ -160,7 +162,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 			require.Equal("d2", resp[0].Id)
 		}
 
-		err = s.StatusReportPut(false, serverptypes.TestStatusReport(t, &pb.StatusReport{
+		err = s.StatusReportPut(ctx, false, serverptypes.TestStatusReport(t, &pb.StatusReport{
 			Id:          "d3",
 			Application: app,
 			Workspace:   ws,
@@ -172,14 +174,14 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.StatusReportList(app)
+			resp, err := s.StatusReportList(ctx, app)
 			require.NoError(err)
 
 			require.Len(resp, 3)
 		}
 
 		{
-			resp, err := s.StatusReportList(app,
+			resp, err := s.StatusReportList(ctx, app,
 				serverstate.ListWithOrder(&pb.OperationOrder{
 					Order: pb.OperationOrder_START_TIME,
 					Desc:  true,
@@ -201,7 +203,7 @@ func TestStatusReport(t *testing.T, factory Factory, restartF RestartFactory) {
 			require.Equal("d3", resp[0].Id)
 		}
 		{
-			resp, err := s.StatusReportList(app,
+			resp, err := s.StatusReportList(ctx, app,
 				serverstate.ListWithOrder(&pb.OperationOrder{
 					Order: pb.OperationOrder_START_TIME,
 					Desc:  true,
