@@ -13,7 +13,7 @@ export default class extends Component<Args> {
 
   get states(): unknown {
     return this.args.statusReport.resourcesList
-      ? this.args.statusReport.resourcesList.map((r) => JSON.parse(r.stateJson ?? '{}'))
+      ? this.args.statusReport.resourcesList.map(stateFromResource)
       : [];
   }
 
@@ -21,3 +21,12 @@ export default class extends Component<Args> {
     return findImageRefs(this.states);
   }
 }
+
+function stateFromResource(resource: StatusReport.Resource.AsObject): unknown {
+  try {
+    return JSON.parse(resource.stateJson);
+  } catch (error) {
+    console.error('Could not parse stateJson for resource', resource);
+    return {};
+  }
+}
