@@ -40,7 +40,7 @@ Router.map(function () {
     this.route('projects', { path: '/' }, function () {
       this.route('project', { path: '/:project_id' }, function () {
         this.route('apps', function () {
-          this.route('new');
+          this.route('create');
         });
         this.route('app', { path: '/app/:app_id' }, function () {
           this.route('builds');
@@ -66,7 +66,7 @@ Router.map(function () {
           this.route('config-variables');
         });
       });
-      this.route('new');
+      this.route('create');
     });
   });
 });
