@@ -1,5 +1,5 @@
 import { Model, belongsTo, hasMany } from 'ember-cli-mirage';
-import { Build } from 'waypoint-pb';
+import { Build, Job } from 'waypoint-pb';
 
 export default Model.extend({
   application: belongsTo(),
@@ -18,6 +18,7 @@ export default Model.extend({
     result.setComponent(this.component?.toProtobuf());
     result.setId(this.id);
     result.setJobId(this.JobId);
+    result.setPreload(this.preloadProtobuf());
     result.setSequence(this.sequence);
     result.setStatus(this.status?.toProtobuf());
     result.setTemplateData(this.templateData);
@@ -29,4 +30,20 @@ export default Model.extend({
 
     return result;
   },
+
+  preloadProtobuf(): Build.Preload {
+    let result = new Build.Preload();
+
+    if (this.gitCommitRef) {
+      let dataSourceRef = new Job.DataSource.Ref();
+      let gitRef = new Job.Git.Ref();
+
+      gitRef.setCommit(this.gitCommitRef);
+      dataSourceRef.setGit(gitRef);
+
+      result.setJobDataSourceRef(dataSourceRef);
+    }
+
+    return result;
+  },
 });
